@@ -8,5 +8,5 @@ ejes = pilas.actores.Ejes()
 ejes.x = 100
 ejes.y = 100
 
-pilas.avisar("Ejes desplazados. Pulas F12 para ver los reales.")
+pilas.avisar("Ejes desplazados. Pulas F12 para ver su posición")
 pilas.ejecutar()
