@@ -1,11 +1,14 @@
 # -*- encoding: utf-8 -*-
 import pilas
+# Permite que este ejemplo funcion incluso si no has instalado pilas.
+import sys
+sys.path.insert(0, "..")
 
 
 pilas.iniciar()
 
 actor = pilas.actores.Actor()
-animacion = pilas.imagenes.Grilla("pingu.png", 10)
+animacion = pilas.imagenes.cargar_grilla("pingu.png", 10)
 animacion.asignar(actor)
 
 def avanzar_cuadro(*k, **kv):
